{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/form.min.js' %}"
    integrity="sha512-ln1VzEG3ExrwRcfqIxE9WUXh81N4t2LJSq+bLrMGx4m1X/kwxbtSpDGD7EMwsDgtRCxKecPrnvw2VRf5lG8M9w=="
    crossorigin="anonymous"
></script>
