{% load static %}

<script
    src="{% static 'aasrp/libs/x-editable/1.5.4/bootstrap5-editable/js/bootstrap-editable.min.js' %}"
    integrity="sha512-GpwuhZ2LkD9jnasqgssH1FJQLHvIeW9T36ax9W3dv+8KSA3xURDoTffS1SD95KSb2fXuYWg0Z5sDoZ/Xx10GHA=="
    crossorigin="anonymous"
></script>
