{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/my-srp-requests.min.js' %}"
    integrity="sha512-NQbSkfZTibTRcEPhfk1I0Pdcm+7PmJj7mqhtsBa5cDtZSkJAu/pde4y30xglU1LlxMqpYVGd7Veo4wFmnGfhrw=="
    crossorigin="anonymous"
></script>
