{% load aasrp %}

<link
    rel="stylesheet"
    href="{% aasrp_static 'aasrp/css/aa-srp-form.min.css' %}"
    integrity="sha512-y6ANPtPgBNxGQhYYNN3EI5bpLtzy/IVAJ18I5MdjnCIel2fCnD34H3dkHdOpt8ZiaKb9T/NRjS5rxlQynP9hlQ=="
    crossorigin="anonymous"
>
