{% load static %}

<link
    rel="stylesheet"
    href="{% static 'aasrp/libs/x-editable/1.5.4/bootstrap5-editable/css/bootstrap-editable.min.css' %}"
    integrity="sha512-52DL7BCZnjDkln1qrZMe9qSt6KFBwrGAa4JqmrmwYrz+QIfBXyacLvmTrpIyqJdjcEqzw/3YOM4Xj32mDz4x3A=="
    crossorigin="anonymous"
>
