{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/view-requests.min.js' %}"
    integrity="sha512-yw3e6+eCTsADypfOFBC6/SJef8wxPzgO27xRo8qck9rSkPtZ1mIx1RvB1NgZ3HD80GrxCo9dMdcX6hLLRnnjtQ=="
    crossorigin="anonymous"
></script>
