{% load i18n %}
{% load navactive %}

<li class="nav-item" role="presentation">
    {% if perms.aasrp.manage_srp %}
        {% if request.resolver_match.url_name == "srp_links_all" %}
            {% url 'aasrp:srp_links_all' as url_srp_links %}
        {% else %}
            {% url 'aasrp:srp_links' as url_srp_links %}
        {% endif %}
    {% else %}
        {% url 'aasrp:srp_links' as url_srp_links %}
    {% endif %}

    <a
        class="nav-link {% navactive request 'aasrp:srp_links aasrp:srp_links_all' %}"
        href="{{ url_srp_links }}"
    >
        {% if perms.aasrp.manage_srp %}
            {% if request.resolver_match.url_name == "srp_links_all" %}
                {% translate "SRP links (all)" %}
            {% else %}
                {% translate "SRP links (active)" %}
            {% endif %}
        {% else %}
            {% translate "SRP links" %}
        {% endif %}
    </a>
</li>

<li class="nav-item" role="presentation">
    <a
        class="nav-link {% navactive request 'aasrp:own_srp_requests' %}"
        href="{% url 'aasrp:own_srp_requests' %}"
    >
        {% translate "My SRP requests" %}
    </a>
</li>

<li class="nav-item" role="presentation">
    <a
        class="nav-link {% navactive request 'aasrp:user_settings' %}"
        href="{% url 'aasrp:user_settings' %}"
    >
        {% translate "My settings" %}
    </a>
</li>
