{% load aasrp %}

<link
    rel="stylesheet"
    href="{% aasrp_static 'aasrp/css/aa-srp.min.css' %}"
    integrity="sha512-eeN/pqBQ+41AVmNR+UyHjrSZvK0fpd5c14yV4NHnQEEXseMMZQu794m/PJ4usfZyQnZS2t4kFWDusnWZhC+HWw=="
    crossorigin="anonymous"
>
