{% load aasrp %}

<script
    src="{% aasrp_static 'aasrp/javascript/srp-links.min.js' %}"
    integrity="sha512-AFhrcKlw01lbcRMeUzZtVDFpUtWR/xcPNLnCs+vfCdRiJiwgxXpiplybiAAnAqbCILg+Q6/tHMRkbWf1l0R7AQ=="
    crossorigin="anonymous"
></script>
